SobotApi class

Constructors

SobotApi()

Properties

closeSobotChatMethod ↔ String
getter/setter pair
getUnReadMessageMethod ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
messageLinkClickMethod ↔ String
getter/setter pair
openSobotHelpCenterMethod ↔ String
getter/setter pair
openSobotHelpMallCenterMethod ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startZhichiMethod ↔ String
getter/setter pair

Methods

closeSobotChat(dynamic params) → Future
getUnReadMessage(dynamic partnerid) → Future
messageLinkClic() → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openSobotHelpCenter(dynamic initParams) → Future
openSobotHelpMallCenter(dynamic initParams) → Future
startZhichi(dynamic initParams) → Future
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

sobotMethodChannel → const MethodChannel